@@ -40,17 +40,7 @@ class Storage(driver.Base):
         object_instance = self._jss.bucket(self._bucket).object(path1)
         
         return object_instance.generate_url("GET")
-#    
-#    def get_json(self, path):
-#        logger.info("get_json path:%s" % path)
-#        try:
-#            result = json.loads(self.get_unicode(path))
-#            logger.info("get_json result:%s" % result)
-#            return result
-#        except Exception as e:
-#            logger.error("get_json error:%s" % e)
-#            return []
-#        
+
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
@@ -104,20 +94,6 @@ class Storage(driver.Base):
             raise e
         return path
 
-
-#    def stream_write(self, path, fp):
-#        logger.info("stream_write path:%s" % path)
-#        path1 = self._init_path(path)
-#        part_size = 5 * 1024 * 1024
-#        if self.buffer_size < part_size:
-#            part_size = self.buffer_size
-#        try:
-#             object_instance = self._jss.bucket(self._bucket).object(path1)
-#             object_instance.multi_upload_fp(None, fp, part_size)
-#        except Exception as e :
-#            logger.error("stream_write error:%s" % e)
-#            raise e
-
     def list_directory(self, path=None):
         logger.info("list_directory path:%s" % path)
         path1 = self._init_path(path)
@@ -140,45 +116,45 @@ class Storage(driver.Base):
             logger.error("list_directory error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
         
-    def stream_write(self, path, fp):
-         logger.info("stream_write path:%s " % path)
-         path1 = self._init_path(path)
-
-         try:
-             object_instance = self._jss.bucket(self._bucket).object(path1)
-             l = fp.read(self.buffer_size)
-             logger.info("stream_write,begin to write the content to jss ")
-             while len(l) > 0:
-                 object_instance.upload_flow(None, l, True)
-                 l = fp.read(self.buffer_size)
-         except IOError as e :
-            logger.error("stream_write error:%s" % e)
-         
 #    def stream_write(self, path, fp):
-#        logger.info("stream_write path:%s" % path)
-#        path1 = self._init_path(path)
-#        part_size = 5 * 1024 * 1024
-#        if self.buffer_size < part_size:
-#            part_size = self.buffer_size
-#        
-#        try:
-#            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
-#            with open(tmp_file, 'w') as f:
-#                while True:
-#                    buf = fp.read(part_size)
-#                    if not buf: break
-#                    f.write(buf)
-#                
-#            with open(tmp_file, 'r') as fp:
-#                object_instance = self._jss.bucket(self._bucket).object(path1)
-#                object_instance.multi_upload_fp(None, fp, part_size)
-#                
-#        except Exception as e :
-#             logger.error("stream_write error:%s" % e)
-#             raise e
-#        finally:
-#            if os.path.exists(tmp_file):
-#                os.remove(tmp_file)
+#         logger.info("stream_write path:%s " % path)
+#         path1 = self._init_path(path)
+#
+#         try:
+#             object_instance = self._jss.bucket(self._bucket).object(path1)
+#             l = fp.read(self.buffer_size)
+#             logger.info("stream_write,begin to write the content to jss ")
+#             while len(l) > 0:
+#                 object_instance.upload_flow(None, l, True)
+#                 l = fp.read(self.buffer_size)
+#         except IOError as e :
+#            logger.error("stream_write error:%s" % e)
+         
+    def stream_write(self, path, fp):
+        logger.info("stream_write path:%s" % path)
+        path1 = self._init_path(path)
+        part_size = 5 * 1024 * 1024
+        if self.buffer_size < part_size:
+            part_size = self.buffer_size
+        
+        try:
+            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
+            with open(tmp_file, 'w') as f:
+                while True:
+                    buf = fp.read(part_size)
+                    if not buf: break
+                    f.write(buf)
+                
+            with open(tmp_file, 'r') as fp:
+                object_instance = self._jss.bucket(self._bucket).object(path1)
+                object_instance.multi_upload_fp(None, fp, part_size)
+                
+        except Exception as e :
+             logger.error("stream_write error:%s" % e)
+             raise e
+        finally:
+            if os.path.exists(tmp_file):
+                os.remove(tmp_file)
         
 
     @lru.remove
